@@ -1,8 +1,8 @@
 !== Command line arguments parser
 !
 ! Authors::   Yasuhiro MORIKAWA
-! Version::   $Id: dc_args.f90,v 1.6 2006/11/17 13:48:59 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20061118 $
+! Version::   $Id: dc_args.f90,v 1.9 2006/12/26 14:35:21 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070101 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -66,9 +66,9 @@ module dc_args
   !       character(STRING) :: VAL_namelist
   !
   !       call Open(arg)
-  !       call Option(arg, StoA('-s', '--size'), &
+  !       call Option(arg, StoA('s', 'size'), &
   !         & OPT_size, help="Return number of arguments")
-  !       call Option(arg, StoA('-N', '--namelist'), &
+  !       call Option(arg, StoA('N', 'namelist'), &
   !         & OPT_namelist, VAL_namelist, help="Namelist filename")
   !       call Debug(arg); call Help(arg) ; call Strict(arg)
   !
@@ -199,7 +199,7 @@ module dc_args
   end interface
 
   interface Put_Line
-    module procedure DCArgsPut_Line
+    module procedure DCArgsPutLine
   end interface
 
   interface Debug
@@ -351,6 +351,7 @@ contains
     character(len = *), intent(in), optional :: help
     integer :: i, j, options_size, table_size
     type(OPT_ENTRY), allocatable :: local_tables(:)
+    character(len = STRING) :: opt_name, opt_value, opt_full
     character(len = *), parameter  :: subname = 'DCArgsOption'
   continue
     flag = .false.
@@ -364,8 +365,10 @@ contains
       return
     end if
 
+    !-----------------------------------
     !== ¤ ARGS ؤΥإץåѤξϿ
     !=== ޤϥơ֥ arg % opt_table Ĺ.
+    !-----------------------------------
     table_size = size(arg % opt_table)
     allocate(local_tables(table_size))
     local_tables(1:table_size) = arg % opt_table(1:table_size)
@@ -373,7 +376,7 @@ contains
     allocate(arg % opt_table(table_size + 1))
     arg % opt_table(1:table_size) = local_tables(1:table_size)
     deallocate(local_tables)
-    !=== ͤ
+    !----- ͤ -----
     allocate(arg % opt_table(table_size + 1) % options(options_size))
     arg % opt_table(table_size + 1) % options = options
     arg % opt_table(table_size + 1) % help_message = ''
@@ -382,12 +385,29 @@ contains
     end if
     arg % opt_table(table_size + 1) % optvalue_flag = present(value)
 
+    !----- options  -----
+    do i = 1, options_size
+      opt_full = arg % opt_table(table_size + 1) % options(i)
+      if (DCOptionFormC(opt_full, opt_name, opt_value)) then
+        arg % opt_table(table_size + 1) % options(i) = opt_name
+      else
+        if (len(trim(adjustl(opt_full))) < 2) then
+          arg % opt_table(table_size + 1) % options(i) = &
+            & '-' // trim(adjustl(opt_full))
+        else
+          arg % opt_table(table_size + 1) % options(i) = &
+            & '--' // trim(adjustl(opt_full))
+        end if
+      end if
+    end do
+
     ! arg % cmd_opts_list õ flag, value ؤ
     ! ƤФ줿Τ˴ؤƤ arg % cmd_opts_list % flag_called 
     ! .true. 
     do i = 1, options_size
       do j = 1, size(arg % cmd_opts_list)
-        if (trim(options(i)) == trim(arg % cmd_opts_list(j) % name)) then
+        if (trim(arg % opt_table(table_size + 1) % options(i)) &
+          &             == trim(arg % cmd_opts_list(j) % name)) then
           flag = .true.
           if (present(value)) then
             value = arg % cmd_opts_list(j) % value
@@ -449,7 +469,7 @@ contains
     ! إץåɽ, Option, HelpMsg ֥롼
     ! ˤäղä뤳ȤǽǤ.
     !
-    use dc_types, only: STRING
+    use dc_types, only: STRING, STDOUT
     use dc_string, only: StoA, StoI, Printf, Concat, JoinChar, UChar, LChar
     use dc_present, only: present_and_true
     use dc_message, only: MessageNotify
@@ -474,7 +494,7 @@ contains
       return
     end if
     if (trim(VAL_help) == '') then
-      unit = 6
+      unit = STDOUT
     else
       unit = StoI(VAL_help)
     end if
@@ -561,7 +581,7 @@ contains
     !       integer :: i
     !
     !       call Open(arg)
-    !       call HelpMsg(arg, 'Title', 'dcargs $Revision: 1.6 $ :: Test program of dc_args')
+    !       call HelpMsg(arg, 'Title', 'dcargs $Revision: 1.9 $ :: Test program of dc_args')
     !       call HelpMsg(arg, 'Usage', 'dcargs [Options] arg1, arg2, ...')
     !       call Option(arg, StoA('-N', '--namelist'), & 
     !         & OPT_namelist, VAL_namelist, help="Namelist filename")
@@ -700,47 +720,48 @@ contains
     result = size(cmd_argv_list)
   end function DCArgsNumber
 
-  subroutine DCArgsPut_Line(arg)
+  subroutine DCArgsPutLine(arg)
     !
     !=== ΰ
     !
     ! *arg* ˴ؤɸϤɽޤ.
     !
+    use dc_types, only: STDOUT
     use dc_string, only: Printf, JoinChar
     implicit none
     type(ARGS), intent(in) :: arg
     integer :: i
   continue
     if (.not. arg % initialized) then
-      call Printf(6, '#<ARGS:: @initialized=%y>', l=(/arg % initialized/))
+      call Printf(STDOUT, '#<ARGS:: @initialized=%y>', l=(/arg % initialized/))
       return
     end if
-    call Printf(6, '#<ARGS:: @initialized=%y,', l=(/arg % initialized/))
-    call Printf(6, '  @opt_table(:)=')
+    call Printf(STDOUT, '#<ARGS:: @initialized=%y,', l=(/arg % initialized/))
+    call Printf(STDOUT, '  @opt_table(:)=')
     do i = 1, size(arg % opt_table)
-      call Printf(6, '    #<OPT_ENTRY:: ')
-      call Printf(6, '      @options=%c, @help_message=%c, @optvalue_flag=%y', &
+      call Printf(STDOUT, '    #<OPT_ENTRY:: ')
+      call Printf(STDOUT, '      @options=%c, @help_message=%c, @optvalue_flag=%y', &
         & c1=trim(JoinChar(arg % opt_table(i) % options)), &
         & c2=trim(arg % opt_table(i) % help_message), &
         & l=(/arg % opt_table(i) % optvalue_flag/))
-      call Printf(6, '    >')
+      call Printf(STDOUT, '    >')
     end do
-    call Printf(6, '  ,')
-    call Printf(6, '  @cmd_opts_list(:)=')
+    call Printf(STDOUT, '  ,')
+    call Printf(STDOUT, '  @cmd_opts_list(:)=')
     do i = 1, size(arg % cmd_opts_list)
-      call Printf(6, '    #<CMD_OPTS_INTERNAL:: ')
-      call Printf(6, '      @name=%c, @value=%c, @flag_called=%y', &
+      call Printf(STDOUT, '    #<CMD_OPTS_INTERNAL:: ')
+      call Printf(STDOUT, '      @name=%c, @value=%c, @flag_called=%y', &
         & c1=trim(arg % cmd_opts_list(i) % name), &
         & c2=trim(arg % cmd_opts_list(i) % value), &
         & l=(/arg % cmd_opts_list(i) % flag_called/))
-      call Printf(6, '    >')
+      call Printf(STDOUT, '    >')
     end do
-    call Printf(6, '  ,')
-    call Printf(6, '  @cmd_argv_list(:)=%c', &
+    call Printf(STDOUT, '  ,')
+    call Printf(STDOUT, '  @cmd_argv_list(:)=%c', &
       & c1=trim(JoinChar(cmd_argv_list)))
-    call Printf(6, '>')
+    call Printf(STDOUT, '>')
 
-  end subroutine DCArgsPut_Line
+  end subroutine DCArgsPutLine
 
   subroutine PrintAutoLinefeed(unit, fmt, length, indent)
     !
@@ -754,7 +775,7 @@ contains
     ! ϥǥեȤɸϤȤʤޤ. *unit* ˽ֹ
     ! ꤹ뤳ȤǽѹǤޤ.
     !
-    use dc_types, only: STRING
+    use dc_types, only: STRING, STDOUT
     use dc_string, only: Split
     implicit none
     character(*), intent(in) :: fmt
@@ -763,14 +784,14 @@ contains
     integer,      intent(in), optional :: unit   ! 
     character(STRING), pointer :: carray_tmp(:) => null()
     character(STRING) :: store_str
-    integer, parameter :: default_len = 70, default_unit = 6
+    integer, parameter :: default_len = 70
     integer :: i, split_len, indent_len, unit_num
     logical :: new_line_flag
   continue
     if (present(unit)) then
       unit_num = unit
     else
-      unit_num = default_unit
+      unit_num = STDOUT
     end if
 
     if (present(indent)) then
