@@ -1,13 +1,11 @@
-!== dc_error.f90 - 顼
+!== 顼
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: dc_error.f90,v 1.9 2006/10/09 10:35:42 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20061118 $
+! Version::   $Id: dc_error.f90,v 1.12 2006/12/24 20:20:24 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070101 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
-! This file provides dc_error
-!
 module dc_error
   !
   != 顼ѥ⥸塼
@@ -27,15 +25,15 @@ module dc_error
   !   顼ˤϤ <tt>.true.</tt> ˤޤ
   !   err ά줿ϾƱ
   !
-  ! νϤ٤ dc_error ⥸塼 StoreError
-  ! ֥롼ǹԤäƤޤѻͤʤɤ˴ؤƤ StoreError
+  ! νϤ٤ *dc_error* ⥸塼 *StoreError*
+  ! ֥롼ǹԤäƤޤѻͤʤɤ˴ؤƤ *StoreError*
   ! 򻲾ȤƤ
   !
   !
   !== 顼ɰ
   !
   ! gt4f90io 饤֥˥ɤɲäץޤŬڤ
-  ! 顼ɤ StoreError ƤӽФ褦ˤʤФʤޤ
+  ! 顼ɤ *StoreError* ƤӽФ褦ˤʤФʤޤ
   ! ǡ 顼ɤɬפ뤫ɤ
   ! Ƚꤹ뤿ˡ 顼ɤͤбåޤ
   ! 顼ɥˡ˥åѤ뤿ˤϡ
@@ -46,8 +44,7 @@ module dc_error
   ! ޤ <b><tt>USR_E</tt></b> ǻϤޤ̾ϳơΥ桼
   ! ɤ顼ɤǤ
   !
-  ! 顼ǤϤʤ֤ɽ󥨥顼ɤ
-  ! DC_NOERR ( 0) Ǥ
+  ! 顼ǤϤʤ֤ɽ󥨥顼ɤ *DC_NOERR* Ǥ
   !
   ! 顼ɤοͤߤΤϡʥ顼ɤ
   ! Ƥݤλؿˤ򼨤Ǥ
@@ -196,8 +193,7 @@ module dc_error
   !            <b></b> :: dimension variable has another dimension
   !
   ! -105    :: [ <b>GT_EBADDIMNAME     </b> ]
-  !            <b></b> :: <i>string_c</i> ޤ <i>string_s</i>:
-  !                       unknown dimension name
+  !            <b></b> :: <i>cause_c</i>: unknown dimension name
   !
   ! -106    :: [ <b>GT_ENOTVAR         </b> ]
   !            <b></b> :: variable not opened
@@ -209,7 +205,7 @@ module dc_error
   !            <b></b> :: specified dimensional variable not on the same file
   !
   ! -109    :: [ <b>GT_EARGSIZEMISMATCH</b> ]
-  !            <b></b> :: arguments (<i>string_c</i>) array size mismatch
+  !            <b></b> :: arguments (<i>cause_c</i>) array size mismatch
   !
   ! -110    :: [ <b>GT_ENOMATCHDIM     </b> ]
   !            <b></b> :: dimension matching failed
@@ -236,7 +232,7 @@ module dc_error
   !            <b></b> :: invalid allocated size
   !
   ! -118    :: [ <b>GT_ERANKMISMATCH</b> ]
-  !            <b></b> :: rank of data and argument is mismatch (<i>string_c</i>)
+  !            <b></b> :: rank of data and argument is mismatch (<i>cause_c</i>)
   !
   ! -299  :: <b>                     </b>
   !            <b></b> :: ( gtdata ؤΥ顼åΤͽ)
@@ -255,13 +251,36 @@ module dc_error
   !            <b></b> :: ( GrADS 󥿡եؤ
   !                       顼åΤͽ)
   !
+  !=== dc 桼ƥƥѥ顼
+  !
+  ! ʲΥ顼ɤ˴ؤƤ dc_error ⥸塼Ѥ뤳Ȥ
+  ! ѤƤ
+  !
+  ! <b></b> :: <b>  [ ˡ˥å ] 顼å </b>
+  !
+  ! -400    :: [ <b>DC_ENOTINIT          </b> ]
+  !            <b></b> :: object (<i>cause_c</i>) is not initialized
+  !
+  ! -401    :: [ <b>DC_EBADUNIT</b> ]
+  !            <b></b> :: unit (<i>cause_c</i>) is invalid
+  !
+  ! -402    :: [ <b>DC_EBADCALTYPE</b> ]
+  !            <b></b> :: calendar type (<i>cause_i</i>) is invalid
+  !
+  ! -403    :: [ <b>DC_EBADTIMEZONE</b> ]
+  !            <b></b> :: time zone (<i>cause_c</i>) is invalid
+  !
+  ! -402-499  :: <b>                     </b>
+  !                <b></b> :: ( gt4f90io 
+  !                           顼åΤͽ)
+  !
   !=== gt4f90io ˴ؤͽ󤷤Ƥ륨顼
   !
   ! ʲΥ顼ɤϺγĥͤͽ󤷤ƤʬǤ
   !
   ! <b></b> :: <b>  [ ˡ˥å ] 顼å </b>
   !
-  ! -400-999  :: <b>                     </b>
+  ! -500-999  :: <b>                     </b>
   !                <b></b> :: ( gt4f90io 
   !                           顼åΤͽ)
   !
@@ -273,10 +292,10 @@ module dc_error
   ! <b></b> :: <b>  [ ˡ˥å ] 顼å </b>
   !
   ! -1000   :: [ <b>USR_ECHAR          </b> ]
-  !            <b></b> :: <i>string_c</i>
+  !            <b></b> :: <i>cause_c</i>
   !
   ! -1001   :: [ <b>USR_EINT           </b> ]
-  !            <b></b> :: <i>string_c</i> (<i>string_i</i>)
+  !            <b></b> :: <i>cause_c</i> (<i>cause_i</i>)
   !
   !
 
@@ -329,6 +348,14 @@ module dc_error
   !
   integer, parameter, public:: GR_ENOTGR = -300
 
+  !
+  ! -400 ʲ: dc 桼ƥƥΥ顼
+  !
+  integer, parameter, public:: DC_ENOTINIT     = -400
+  integer, parameter, public:: DC_EBADUNIT     = -401
+  integer, parameter, public:: DC_EBADCALTYPE  = -402
+  integer, parameter, public:: DC_EBADTIMEZONE = -403
+
   !
   ! -1000 ʲ: 桼
   !
@@ -411,6 +438,18 @@ contains
     case(GR_ENOTGR)
       msg = " invalid GrADS file"
       !
+      ! -400 ʲ: DC 桼ƥƥΥ顼
+      !
+    case(DC_ENOTINIT)
+      msg = " object (" // trim(cause_string) //") is not initialized"
+    case(DC_EBADUNIT)
+      msg = " unit (" // trim(cause_string) //") is invalid"
+    case(DC_EBADCALTYPE)
+      write(message, "(' calendar type (', i4, ') is invalid')") cause_int
+      msg = trim(message)
+    case(DC_EBADTIMEZONE)
+      msg = " time zone (" // trim(cause_string) //") is invalid"
+      !
       ! -1000 ʲ: 桼
       !
     case(USR_ECHAR)
@@ -466,8 +505,9 @@ contains
     ! Ȥ StoreError Ѥ뤳ȤꤷUSR_ECHAR  USR_EINT
     ! ѰդƤޤ Υ顼ɤѤȡ
     ! StoreError ϰʲηʸ "*" ˽Ϥƥץ
-    ! λޤ ʤ°פ˻ȤåѡȤ 
-    ! dc_message ⥸塼ѰդƤΤǤ⻲ȤƤ
+    ! λޤ°פ˻ȤåϤӥ顼ȯ
+    ! Υ⥸塼Ȥ *dc_message* ѰդƤΤ
+    ! ⻲ȤƤ
     !
     !     
     !     *** ERROR (Code USR_ECHAR) [where] ***  cause_c
@@ -480,8 +520,8 @@ contains
     ! 顼ֹ number  errno ˳Ǽ롣ƱտŪ
     ! where, cause_i  cause_location, cause_string,
     ! cause_int ˳Ǽ롣 
-    ! err ͿƤ硢err  number  0 ξˤʤ롣
-    ! number  0 ʤ¨롣
+    ! err ͿƤ硢err  number  DC_NOERR ξˤʤ롣
+    ! number  DC_NOERR ʤ¨롣
     ! err ͿƤʤХ顼å * ˽Ϥ
     ! ץλ롣
     !++
