@@ -1,8 +1,8 @@
 !== dc_trace.f90 - ǥХåѥ⥸塼
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: dc_trace.f90,v 1.7 2006/10/09 10:35:42 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20061118 $
+! Version::   $Id: dc_trace.f90,v 1.8 2006/12/05 21:29:32 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070101 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -285,6 +285,8 @@ contains
   end subroutine Dbg_Scratch
 
   subroutine SetDebug(debug)
+    use dc_types, only: STDOUT, STDERR
+    implicit none
     !
     !== ǥХå⡼ɤ򥪥󥪥
     !
@@ -315,12 +317,12 @@ contains
       if (ios == 0) return
     else
       ! debug Ϳ̵ֹ 0 (ɸ२顼)
-      dbg = 0
-      write(dbg, "(A, 'SetDebug: dbg = 0')", iostat=ios) trim(head)
+      dbg = STDERR
+      write(dbg, "(A, 'SetDebug: dbg = ', I0)", iostat=ios) trim(head), dbg
       if (ios == 0) return
       ! ֹ 0 ؤνϤԤֹ 6 (ɸ)
-      dbg = 6
-      write(dbg, "(A, 'SetDebug: dbg = 6')", iostat=ios) trim(head)
+      dbg = STDOUT
+      write(dbg, "(A, 'SetDebug: dbg = ', I0)", iostat=ios) trim(head), dbg
       if (ios == 0) return
     endif
     ! 㳰Ȥ dbg ν
