@@ -1,8 +1,8 @@
 !== Kind type parameter value
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: dc_types.f90,v 1.7 2006/06/09 05:28:40 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20061118 $
+! Version::   $Id: dc_types.f90,v 1.9 2006/12/05 21:24:42 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070101 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -19,8 +19,8 @@ module dc_types
   implicit none
   private
   public :: DP
-  public :: TOKEN
-  public :: STRING
+  public :: TOKEN, STRING
+  public :: STDIN, STDOUT, STDERR
   public :: NF_KIND_INT1
   public :: NF_KIND_INT2
 
@@ -33,7 +33,7 @@ module dc_types
                                          ! ʸѿμ̷ѥ᥿
                                          ! ȤѤޤ
 
-  integer, parameter:: STRING = 255      ! String.
+  integer, parameter:: STRING = 256      ! String.
                                          ! ʸݻ
                                          ! ʸѿμ̷ѥ᥿
                                          ! ȤѤޤ
@@ -41,17 +41,24 @@ module dc_types
                                          !--
                                          !ȯԸ
                                          !
-                                         ! 255 Ȥͤ˿ͳϤޤ.
+                                         ! 256 Ȥͤ˿ͳϤޤ.
                                          ! ɬפʤФ礭ͤ
                                          ! Ƥ⹽ޤ.
+                                         !  8 ХȶȤʤ褦,
+                                         ! 8 ܿȤʤäƤ뤳Ȥ
+                                         ! 侩ޤ.
                                          !
-                                         ! , SR11000 κŬ
+                                         ! SR11000 κŬ
                                          ! FORTRAN90 Ѥ
-                                         !  255 ʲ˻ꤹɬפ
-                                         ! ޤ.
+                                         ! Ϥ 255 ʲ
+                                         ! ꤹɬפޤ.
                                          !
                                          !++
 
+  integer, parameter:: STDIN  = 5        ! ɸϤֹ
+  integer, parameter:: STDOUT = 6        ! ɸϤֹ
+  integer, parameter:: STDERR = 0        ! ɸ२顼Ϥֹ
+
   ! netCDF Fortran 󥿡եηѥ᥿
   ! (netcdf.inc ˤ¸ߤʤ)
   !
