@@ -1,8 +1,8 @@
 !== dc_units.f90 - ñ̷Ͻѥ⥸塼
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: dc_units.f90,v 1.3 2005/12/26 15:10:12 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20061118 $
+! Version::   $Id: dc_units.f90,v 1.4 2006/12/30 08:21:55 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070101 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -61,7 +61,7 @@ contains
 
   subroutine units_simplify(u, name, power)
     type(UNITS), intent(inout):: u
-    character(TOKEN), intent(in):: name(u%nelems)
+    character(*), intent(in):: name(u%nelems)
     real(DP), intent(in):: power(u%nelems)
     integer:: i, n, j, onazi
     integer:: table(u%nelems)
@@ -262,7 +262,7 @@ contains
     !
     use dcunits_com
     type(UNITS), intent(out):: u
-    character(STRING), intent(in):: cunits
+    character(*), intent(in):: cunits
 
     ! ξ󡢾軻оݤȤݻ롣
     !  shift ڥ졼դñ̤軻ǤʤȤ򼨤
