@@ -1,8 +1,8 @@
 !== Formatted output conversion
 !
 ! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
-! Version::   $Id: dcstringsprintf.f90,v 1.6 2006/10/09 10:35:42 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20061118 $
+! Version::   $Id: dcstringsprintf.f90,v 1.10 2006/12/29 10:29:27 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070101 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -21,13 +21,16 @@
 !    <tt>б</tt> :: ǡμȽϷ
 !
 ! <b><tt>%d, %D</tt></b> ::
-!    <tt>i(:)</tt>       :: ǡ (10 ʿ)  20  ɽ
+!    <tt>i(:)</tt>       :: ǡ (10 ʿ) ɽ. 
+!              %2d  %04d Τ褦'%' θ˿ꤹ뤳Ȥ
+!              ϤѹǤޤ.
+!              '%' ľ夬 0 ξƬ 0 , Ǥʤ϶ޤ.
 !
 ! <b><tt>%o, %O</tt></b> ::
-!    <tt>i(:)</tt>       :: 8 ʿǡ 20 ɽ
+!    <tt>i(:)</tt>       :: 8 ʿǡɽ
 !
 ! <b><tt>%x, %X</tt></b> :: 
-!    <tt>i(:)</tt>       :: 16 ʿǡ 20 ɽ
+!    <tt>i(:)</tt>       :: 16 ʿǡɽ
 !
 ! <b><tt>%f, %F</tt></b> :: 
 !    <tt>d(:)</tt>       :: ټ¿ǡ 80η 40ɽ
@@ -41,9 +44,6 @@
 ! <b><tt>%y, %Y</tt></b> :: 
 !    <tt>L(:)</tt>       :: ǡ yesno ɽ
 !
-! <b><tt>%s, %S</tt></b> :: 
-!    <tt>s(:)</tt>       :: VSTRINGǡ
-!
 ! <b><tt>%c, %C</tt></b> :: 
 !    <tt>c1c2c3</tt> :: ʸǡ (ѿ)
 !
@@ -80,7 +80,7 @@
 !        arrayI2(i) = 345 * i
 !      enddo
 !      eq = (maxval(arrayI1) == minval(arrayI2))
-!      output = CPrintf(fmt="color=%c size=%c int=%d I1=%*d I2=%*d R=%*r equal=%y", &
+!      output = CPrintf(fmt="color=%c size=%c int=%03d I1=%*d I2=%*04d R=%*r equal=%y", &
 !        &              c1=trim(color), c2=trim(size), i=(/int, arrayI1, arrayI2/), &
 !        &              r=(/arrayR/), L=(/eq/), n=(/n1, n2, n1/))
 !   
@@ -128,13 +128,13 @@
 !
 !      ! ֹ 6 (ɸ) ľܽϤ
 !      call Printf(unit=6, &
-!        &         fmt="color=%c size=%c int=%d I1=%*d I2=%*d R=%*r equal=%y", &
+!        &         fmt="color=%c size=%c int=%03d I1=%*d I2=%*04d R=%*r equal=%y", &
 !        &         c1=trim(color), c2=trim(size), i=(/int, arrayI1, arrayI2/), &
 !        &         r=(/arrayR/), L=(/eq/), n=(/n1, n2, n1/))
 !
 !      ! ʸ output Ϥ
 !      call Printf(unit=output, &
-!        &         fmt="color=%c size=%c int=%d I1=%*d I2=%*d R=%*r equal=%y", &
+!        &         fmt="color=%c size=%c int=%03d I1=%*d I2=%*04d R=%*r equal=%y", &
 !        &         c1=trim(color), c2=trim(size), i=(/int, arrayI1, arrayI2/), &
 !        &         r=(/arrayR/), L=(/eq/), n=(/n1, n2, n1/))
 !      write(*,*) trim(output)
@@ -160,20 +160,30 @@ subroutine DCStringSPrintf(unit, fmt, i, r, d, L, n, c1, c2, c3, ca)
   character(*),     intent(in), optional:: ca(:)
 
   ! 嵭Υ
-  integer:: ni, nr, nd, nl, ns, nc, na, nn
+  integer:: ni, nr, nd, nl, nc, na, nn
   integer:: ucur       ! unit ˽񤫤줿ʸ
   integer:: endp       ! ˽줿 fmt ʸ
   integer:: cur        ! ʸ fmt(cur:cur) Ǥ
   integer:: ptr        ! fmt 鸡򤹤Ȥ˻
+  integer:: exp_ptr    ! fmt ͤλؿ򸡺򤹤Ȥ˻
+  integer:: minus_ptr  ! '-' 򸡺˻
   integer:: repeat     ! % ޤ %* ꤵ줿֤
   integer:: m          ! 1:repeat ϰϤư롼ѿ
   integer:: stat       ! 顼
   character(80):: cbuf ! read/write ʸΥХåե
+  character(80):: exp_buf ! real/write ʸλؿΥХåե (¿)
+  character(80):: ibuf ! real/write ʸΥХåե ()
+  integer:: len_ibuf   ! ibuf Ĺ
+  integer:: figs_ibuf  ! ibuf ͭʷ
+  logical:: int_zero_fill ! Ƭ 0 뤫ɤȽꤹե饰 ()
+  integer:: int_figs   ! Ϥݤη ()
 continue
-  ni = 0;  nr = 0;  nd = 0;  nl = 0;  ns = 0;  nc = 0;  na = 0;  nn = 0
+  ni = 0;  nr = 0;  nd = 0;  nl = 0;  nc = 0;  na = 0;  nn = 0
   unit = ""
   ucur = 0
   endp = 0
+  int_figs = 0
+  int_zero_fill = .false.
   MainLoop: do
     cur = endp + 1
     if (cur > len(fmt)) exit MainLoop
@@ -208,12 +218,32 @@ continue
       else
         repeat = n(nn)
       endif
-    else if (cbuf == '') then
-      repeat = 1
+      ibuf = cbuf(2:)
     else
-      ptr = verify(cbuf, " 0123456789")
-      if (ptr > 0) cbuf(ptr: ) = " "
-      read(cbuf, "(I80)", iostat=ptr) repeat
+      repeat = 1
+      ibuf = cbuf
+!    else if (cbuf == '') then
+!      repeat = 1
+!    else
+!      ptr = verify(cbuf, " 0123456789")
+!      if (ptr > 0) cbuf(ptr: ) = " "
+!      read(cbuf, "(I80)", iostat=ptr) repeat
+    endif
+    !
+    ! %2d  %04d Τ褦 '%' θ˿ꤵ졢
+    !  d (ѿɽ) ξˤƬ˶
+    ! ޤ 0 .
+    !
+    if (scan(ibuf(1:1),'1234567890') > 0) then
+      if (ibuf(1:1) == '0') then
+        int_zero_fill = .true.
+      else
+        int_zero_fill = .false.
+      end if
+      read(unit=ibuf, fmt="(i80)") int_figs
+    else
+      int_figs = 0
+      int_zero_fill = .false.
     endif
     PercentRepeat: do, m = 1, repeat
       if (m > 1) then
@@ -224,8 +254,26 @@ continue
       case('d', 'D')
         if (.not. present(i)) cycle MainLoop
         ni = ni + 1;  if (ni > size(i)) cycle MainLoop
-        write(cbuf, "(i20)") i(ni)
-        call append(unit, ucur, trim(adjustl(cbuf)), stat)
+        write(ibuf, "(i20)") i(ni)
+        len_ibuf = len(trim(adjustl(ibuf)))
+        figs_ibuf = verify(ibuf, ' ')
+        cbuf = ' '
+        if (int_figs > len_ibuf) then
+          minus_ptr = scan(ibuf, '-')
+          if (int_zero_fill) then
+            if (minus_ptr /= 0) then
+              len_ibuf = len_ibuf - 1
+              figs_ibuf = figs_ibuf + 1
+              cbuf(1:int_figs-len_ibuf) = '-0000000000000000000'
+            else
+              cbuf(1:int_figs-len_ibuf) = '00000000000000000000'
+            end if
+          end if
+          cbuf(int_figs-len_ibuf+1:) = ibuf(figs_ibuf:20)
+        else
+          cbuf = ibuf(figs_ibuf:20)
+        end if
+        call append(unit, ucur, trim(cbuf), stat)
         if (stat /= 0) exit MainLoop
       case('o', 'O')
         if (.not. present(i)) cycle MainLoop
@@ -244,8 +292,15 @@ continue
         nd = nd + 1;  if (nd > size(d)) cycle MainLoop
         write(cbuf, "(g80.40)") d(nd)
         cbuf = adjustl(cbuf)
+        exp_ptr = verify(cbuf, ' 1234567890-+.', back=.TRUE.)
+        exp_buf = ' '
+        if (exp_ptr > 0) then
+          exp_buf = cbuf(exp_ptr: )
+          cbuf(exp_ptr: ) = " "
+        end if
         ptr = verify(cbuf, " 0", back=.TRUE.)
         if (ptr > 0) cbuf(ptr+1: ) = " "
+        cbuf = trim(cbuf) // trim(exp_buf)
         call append(unit, ucur, trim(adjustl(cbuf)), stat)
         if (stat /= 0) exit MainLoop
       case('r', 'R')
@@ -253,8 +308,15 @@ continue
         nr = nr + 1;  if (nr > size(r)) cycle MainLoop
         write(cbuf, "(g80.40)") r(nr)
         cbuf = adjustl(cbuf)
+        exp_ptr = verify(cbuf, ' 1234567890-+.', back=.TRUE.)
+        exp_buf = ' '
+        if (exp_ptr > 0) then
+          exp_buf = cbuf(exp_ptr: )
+          cbuf(exp_ptr: ) = " "
+        end if
         ptr = verify(cbuf, " 0", back=.TRUE.)
         if (ptr > 0) cbuf(ptr+1: ) = " "
+        cbuf = trim(cbuf) // trim(exp_buf)
         call append(unit, ucur, trim(adjustl(cbuf)), stat)
         if (stat /= 0) exit MainLoop
       case('b', 'B')
@@ -273,11 +335,6 @@ continue
           call append(unit, ucur, "no", stat)
           if (stat /= 0) exit MainLoop
         endif
-!!$      case('s', 'S')
-!!$        if (.not. present(S)) cycle MainLoop
-!!$        ns = ns + 1;  if (ns > size(S)) cycle MainLoop
-!!$        call append(unit, ucur, s(ns)%body(1: s(ns)%len), stat)
-!!$        if (stat /= 0) exit MainLoop
       case('c', 'C')
         nc = nc + 1
         if (nc == 1) then
