@@ -1,8 +1,8 @@
 !== netcdf_f77.f90 - netCDF original interface module
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: netcdf_f77.f90,v 1.2 2005/12/29 03:10:58 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20061118 $
+! Version::   $Id: netcdf_f77.f90,v 1.3 2006/12/30 08:21:55 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070101 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -632,7 +632,7 @@ module netcdf_f77
     integer function nf_put_var1_text(ncid, varid, index, chval)
       integer, intent(in)::                ncid, varid
       integer, intent(in)::                index(*)
-      character, intent(in)::                chval
+      character(*), intent(in)::                chval
     end function nf_put_var1_text
 
     integer function nf_put_var1_int1(ncid, varid, index, i1val)
