@@ -1,8 +1,8 @@
 !== regex.f90 - ɽ⥸塼
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: regex.f90,v 1.4 2006/01/02 10:32:50 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20061118 $
+! Version::   $Id: regex.f90,v 1.5 2006/12/30 08:21:55 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070101 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -245,7 +245,7 @@ contains
 
   logical function hit(ipat, c) result(result)
     integer, intent(in):: ipat(:)
-    character, intent(in):: c
+    character(len=*), intent(in):: c
     character(len=*), parameter:: &
       & DIGIT = "0123456789", &
       & XDIGIT = "ABCDEFabcdef", &
